﻿using System;
using System.Collections.ObjectModel;

using Microsoft.UI.Xaml.Controls;
using Microsoft.UI.Xaml;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 메뉴 항목 컬렉션
        /// </summary>
        private ObservableCollection<MenuItem> menuItemCollection =  new ObservableCollection<MenuItem>()
        {
            new MenuItem() { Caption = "인물"  , Symbol = Symbol.People  },
            new MenuItem() { Caption = "소식"  , Symbol = Symbol.Globe   },
            new MenuItem() { Caption = "메시지", Symbol = Symbol.Message },
            new MenuItem() { Caption = "메일"  , Symbol = Symbol.Mail    }
        };

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 메뉴 항목 컬렉션 - MenuItemCollection

        /// <summary>
        /// 메뉴 항목 컬렉션
        /// </summary>
        public ObservableCollection<MenuItem> MenuItemCollection
        {
            get
            {
                return this.menuItemCollection;
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 메뉴 리스트 뷰 항목 클릭시 처리하기 - menuListView_ItemClick(sender, e)

        /// <summary>
        /// 메뉴 리스트 뷰 항목 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void menuListView_ItemClick(object sender, ItemClickEventArgs e)
        {
            this.contentTextBlock.Text = (e.ClickedItem as MenuItem).Caption + " 페이지";
        }

        #endregion
        #region PanePlacement 토글 스위치 토글시 처리하기 - panePlacementToggleSwitch_Toggled(object sender, RoutedEventArgs e)

        /// <summary>
        /// PanePlacement 토글 스위치 토글시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void panePlacementToggleSwitch_Toggled(object sender, RoutedEventArgs e)
        {
            ToggleSwitch toggleSwitch = sender as ToggleSwitch;

            if(toggleSwitch.IsOn)
            {
                this.splitView.PanePlacement = SplitViewPanePlacement.Right;
            }
            else
            {
                this.splitView.PanePlacement = SplitViewPanePlacement.Left;
            }
        }

        #endregion
        #region DisplayMode 콤보 박스 선택 변경시 처리하기 - displayModeCombobox_SelectionChanged(sender, e)

        /// <summary>
        /// DisplayMode 콤보 박스 선택 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void displayModeCombobox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            this.splitView.DisplayMode = (SplitViewDisplayMode)Enum.Parse
            (
                typeof(SplitViewDisplayMode),
                (e.AddedItems[0] as ComboBoxItem).Content.ToString()
            );
        }

        #endregion
        #region 창 배경 콤보 박스 선택 변경시 처리하기 - paneBackgroundCombobox_SelectionChanged(sender, e)

        /// <summary>
        /// 창 배경 콤보 박스 선택 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void paneBackgroundCombobox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            string colorString = (e.AddedItems[0] as ComboBoxItem).Content.ToString();

            VisualStateManager.GoToState(this, colorString, false);
        }

        #endregion
    }
}